<?php

$LANG = array(

# install.php
'L_INSTALL_TITLE'					=> 'Instalaţie',
'L_WRONG_PHP_VERSION'				=> 'PluXml necesită PHP 5 sau o versiune mai mare pentru a lucra.',
'L_SELECT_LANG'						=> 'Alegeţi limba dorită',
'L_INPUT_CHANGE'					=> 'Schimbă',
'L_DEFAULT_CATEGORY_TITLE'			=> 'Categoria 1',
'L_DEFAULT_CATEGORY_URL'			=> 'categoria-1',
'L_DEFAULT_STATIC_TITLE'			=> 'Pagina 1',
'L_DEFAULT_STATIC_URL'				=> 'pagina-1',
'L_DEFAULT_ARTICLE_TITLE'			=> 'Primul Articol',
'L_DEFAULT_ARTICLE_URL'				=> 'primul-articol',
'L_DEFAULT_COMMENT_CONTENT'			=> 'Acesta este primul comentariu !',
'L_ERR_PLUXML_ALREADY_INSTALLED'	=> 'PluXml este deja instalat !',
'L_ERR_MISSING_USER'				=> 'Vă rugăm să introduceti corect numele !',
'L_ERR_MISSING_LOGIN'				=> 'Vă rugăm să introduceti corect username-ul !',
'L_ERR_MISSING_PASSWORD'			=> 'Vă rugăm să introduceti corect parola!',
'L_ERR_PASSWORD_CONFIRMATION'		=> 'Confirmarea parolă incorectă !',
'L_PLUXML_INSTALLATION'				=> 'Instalaţia PluXml',
'L_SITE_DESCRIPTION'				=> 'Site pe baza la Xml !',
'L_VERSION'							=> 'versiunea',
'L_USERNAME'						=> 'Numele Administratorului',
'L_LOGIN'							=> 'Username-ul Administratorului',
'L_PASSWORD'						=> 'Parola',
'L_PASSWORD_CONFIRMATION'			=> 'Confirmarea Parolei',
'L_INPUT_INSTALL'					=> 'Instalează',
'L_TIMEZONE'						=> 'Time Zone',
'L_PWD_VERY_WEAK'					=> 'Parola foarte slabă',
'L_PWD_WEAK'						=> 'Parolă slabă',
'L_PWD_GOOD'						=> 'Parolă bună',
'L_PWD_STRONG'						=> 'Parolă puternică',
);
?>